/*-GNU-GPL-BEGIN-*
RULI - Resolver User Layer Interface - Querying DNS SRV records
Copyright (C) 2003 Everton da Silva Marques

RULI is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

RULI is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with RULI; see the file COPYING.  If not, write to
the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
Boston, MA 02111-1307, USA.
*-GNU-GPL-END-*/

/*
  $Id: ruli.h,v 1.8 2004/05/28 22:17:03 evertonm Exp $
  */


#ifndef RULI_H
#define RULI_H


#include <ruli_mem.h>
#include <ruli_util.h>
#include <ruli_list.h>
#include <ruli_addr.h>
#include <ruli_sock.h>
#include <ruli_txt.h>
#include <ruli_res.h>
#include <ruli_parse.h>
#include <ruli_srv.h>
#include <ruli_search.h>
#include <ruli_smtp.h>
#include <ruli_sync.h>
#include <ruli_getaddrinfo.h>


#endif /* RULI_H */


